#!/usr/bin/python3
#coding:utf-8

# ファイル検索ソフト「PzSearch」：Version7


# Copyright 2017 天杉 善哉 (あますぎ ぜんざい Amasugi Zenzai) All rights reserved.

# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 

import wx
import os
import copy
import re
import time
import sys
import codecs
import fnmatch
from operator import itemgetter
import subprocess
import unicodedata
import threading


#全角を半角2つに換算して文字列の長さを判定する
def halfunit_length( string ):
	length_with_halfsize = 0

	for i in string:
		if unicodedata.east_asian_width( i ) in [ "H", "Na", "N" ]:
			length_with_halfsize += 1

		else:
			length_with_halfsize += 2

	return length_with_halfsize


#ファイル内検索で使用する関数
#文字列を、指定した字数以内で（全角は半角2つ換算で）切り抜く
#lengthが+ならstringの最初から、lengthが-ならstringの最後からlength以内の字数を集める
def textclipping_with_halfunit( string, length ):
	length_with_halfsize = 0
	count = 0
	clipped_string = ""

	#lengthが+ならstringの最初から、lengthが-ならstringの最後からlength以内の字数を集める
	if length > 0:
		count = 0

		for i in range( len( string ) ):

			if unicodedata.east_asian_width( string[ i ] ) in [ "H", "Na", "N" ]:
				count += 1
			else:
				count += 2

			if count > length:
				break

			clipped_string += string[ i ]

	else:
		count = 0

		for i in range( len( string ) ):

			if unicodedata.east_asian_width( string[ len( string ) - 1 - i ] ) in [ "H", "Na", "N" ]:
				count += 1
			else:
				count += 2

			if count > abs( length ):
				break

			clipped_string = string[ len( string ) - 1 - i ] + clipped_string

	return clipped_string


#ファイル内部を検索する関数
def file_contents_search( caller_object, textfile_path, search_word, side_sight = 36, word_regexp = False, word_caps = False ):

	code_list = [ "utf-8", "cp932", "shift_jis", "euc_jp", "iso2022_jp", None ]
	text_code = ""
	result_list = []
	temporary_lines = "" #文字コードの調査時に、試験的にファイルを読み込むためのバッファ
	line_number = 1
	hit_number = 0
	line_header = ""
	line_tale = ""
	detected_part = "" #GUIに表示するための行内容（長いと端を削って略の目印を付ける）

	#変数side_sightの説明 : 該当箇所の先頭の前後にある最大side_sight字を表示用に取得する（最大とは言っても、片側が短ければもう片側をその分伸ばす）

	#非・正規表現の検索処理で使うもの
	line_hitlist = [] #〜.find()の検索結果を収納するリスト
	temporary_oneline = "" #これに行内容をコピーして、小文字に揃える場合でもオリジナルを変更しないようにする
	find_position = 0
	current_position = 0

	#まず、ファイルの文字コードを調べる
	for code in code_list:

		#Noneまで行ったら候補の文字コード全てで読めなかったということなので、関数を終了する
		if code is None:
			return []

		try:
			#Python3以降だと、2までと違って読み込みの段階で弾かれるようなので、読み込みをtryにかける
			f1 = codecs.open( textfile_path , "r", code )
			for line in f1:
				temporary_lines += line
			f1.close()
		except:
			continue

		text_code = code
		break

	#調べた文字コードを元に、読み込んで行ごとに検索していく
	
	try:
		f2 = codecs.open( textfile_path , "r", text_code )
	except:
		return []

	for line in f2:
		line = line.rstrip( '\n' ) #改行削除（￥ｎ）
		line = line.rstrip( '\r' ) #改行削除（￥ｒ）

		if line != "":

			#行の内容を正規表現で検索する
			if word_regexp is True:
				if word_caps is True:
					#大小区別あり
					line_iterator = re.finditer( search_word, line )
				else:
					#大小区別なし
					line_iterator = re.finditer( search_word, line, re.I )

				#正規表現ではない通常検索に揃えるため、イテレータから該当箇所先頭の位置のリストへ変換する
				line_hitlist = [ x.start() for x in line_iterator ]

			#正規表現ではない素の検索
			else:
				#大小の区別なしだと小文字に揃えてからの検索になるため、検索用文字列を別に用意する
				temporary_oneline = ""
				if word_caps is True:
					#大小区別あり
					temporary_oneline = line
					temporary_search_word = search_word
				else:
					#大小区別なし
					temporary_oneline = line.lower()
					temporary_search_word = search_word.lower()

				#1回ごとの該当位置の変数と結果格納用リスト、検索途中の現在位置の変数を初期化
				line_hitlist = []
				find_position = 0
				current_position = 0

				#非・正規表現の検索処理の本体
				#.find()だと最初の1つの該当位置しか示さないので
				#始点をずらしながらループ検索させる必要がある
				while find_position >= 0 and current_position < len( temporary_oneline ):
					find_position = temporary_oneline[ current_position : ].find( temporary_search_word )

					if find_position >= 0:
						line_hitlist.append( current_position + find_position )
						current_position = current_position + find_position + len( temporary_search_word )


			#表示用の（長すぎたら端を切り落とした）行内容を用意して
			#この行の全該当数中の何番目かと一緒に検索結果の辞書に追加する
			for i in line_hitlist:

				hit_number += 1
				hit_pos = i

				#side_sightが負なら、列幅制限をする代わりに左右のカットはしない仕様なので
				#無条件で、行全体をそのまま検出結果として扱う
				if side_sight < 0:
					detected_part = line

				#side_sightで指定字数を超えたら左右をカットする
				else:

					line_header = ""
					line_tale = ""
					#該当箇所の前後が片方だけ？字を越えるかどうかで、前後の上限字数を決める。
					#シェルスクリプト版では、検索語の最初以前と末尾以降を見ていたが
					#検索語が長いと全体も長くなるので、最初以前以降で考慮するようにした。
					if halfunit_length( line ) <= side_sight * 2:
						#行全体が範囲内に収まる場合
						line_header = ""
						line_tale = ""
						detected_part = line

					elif halfunit_length( line[ 0: hit_pos ] ) <= side_sight and halfunit_length( line[ hit_pos: ] ) > side_sight:
						#以前が短く、以降がオーバーしている場合
						line_header = ""
						line_tale = "（後略）"
						detected_part = textclipping_with_halfunit( line, side_sight * 2 )

					elif halfunit_length( line[ 0: hit_pos ] ) > side_sight and halfunit_length( line[ hit_pos: ] ) <= side_sight:
						#以前がオーバーしていて、以降が短い場合
						line_header = "（前略）"
						line_tale = ""
						detected_part = textclipping_with_halfunit( line, side_sight * -2 )

					elif halfunit_length( line[ 0: hit_pos ] ) > side_sight and halfunit_length( line[ hit_pos: ] ) > side_sight:
						#以前も以降もオーバーしている場合
						line_header = "（略）"
						line_tale = "（略）"
						detected_part = textclipping_with_halfunit( line[ 0: hit_pos ], side_sight * -1 ) + textclipping_with_halfunit( line[ hit_pos: ], side_sight )

					else:
						#以前も以降も短い場合（おそらく既に「行全体が範囲内に収まる場合」で該当しているだろうが）
						line_header = ""
						line_tale = ""
						detected_part = line


				result_list.append( { "line" : line_number, "hit" : hit_number, "hit_str" : line_header + detected_part + line_tale } )

		line_number += 1

		#検索中止用の変数がTrueなら、ファイルを閉じて関数を終了する
		if caller_object.get_search_stop_flag() is True:
			f2.close()
			return [ { "line" : 0, "hit" : 0, "hit_str" : "" } ]
	
	f2.close()
	for x in result_list:
		x[ "max_hit" ] = hit_number

	return result_list


#指定された名前、サイズ、更新or作成時刻の範囲といった条件に一致するファイルを探す関数
#ファイル内検索の単語(search_word)が指定されていれば、file_contents_search関数に送る
def search_file( caller_object, target_dir, subdir = True, search_name = "", name_regexp = False, name_caps = False, search_word = "", word_regexp = False, word_caps = False, min_size = 0, max_size = 0, time_point = 0, time_direction = "after", time_mode = "update", side_sight = 36 ):
	filelist = []
	existing_file_list = []
	temporary_list = []
	name_regexp_flag = copy.copy( name_regexp )
	search_word_regexp_check = True

	#各ファイルについてファイル名、パス、サイズ、更新・作成日時を格納した辞書をリストにまとめる
	#このリストをもとに、後の工程でファイル名やサイズでふるいにかけていく
	if subdir is True:
	#サブディレクトリも含めた検索
	
		for i in os.walk( target_dir ):

			#リンク切れになっている「フォルダーへのリンク」がファイルとしてカウントされ
			#エラーを引き起こしていたので、ファイルだと確認できたものだけ抽出する
			existing_file_list = []
			existing_file_list = [ x for x in i[2] if os.path.isfile( os.path.join( i[0], x ) ) ]

			filelist += ( [ { "filename" : x, "filepath" : os.path.join( i[0], x ), "size" : os.path.getsize( os.path.join( i[0], x ) ), "update-time" : os.path.getmtime( os.path.join( i[0], x ) ), "create-time" : os.path.getctime( os.path.join( i[0], x ) ) } for x in existing_file_list ] )

	#サブディレクトリは含めないで、対象フォルダ直下のファイルのリストだけを取得する
	else:
		for i in os.walk( target_dir ):

			#i[0]は、そのとき見ているディレクトリなので、それがtarget_dirと一致したということはiが検索対象ディレクトリ直下の情報ということになる
			if i[0] == target_dir:
				#リンク切れになっている「フォルダーへのリンク」がファイルとしてカウントされ
				#エラーを引き起こしていたので、事前にチェックしてファイルでないならリストから除去
				if i[2] != []:
					for hit in i[2]:
						if not os.path.isfile( os.path.join( i[0], hit ) ):
							i[2].remove( hit )

				filelist = ( [ { "filename" : x, "filepath" : os.path.join( i[0], x ), "size" : os.path.getsize( os.path.join( i[0], x ) ), "update-time" : os.path.getmtime( os.path.join( i[0], x ) ), "create-time" : os.path.getctime( os.path.join( i[0], x ) ) } for x in i[2] ] )

				#検索対象ディレクトリ直下のファイルだけ検出する目的は達成したので、ループを抜ける
				break


	#正規表現検索であっても、検索語が正規表現として成立しない場合（*.txtなど）は
	#エラーになるので、ワイルドカード検索になるようにフラグを変更する。
	if name_regexp_flag is True:
		try:
			re.compile( search_name )

		except:
			name_regexp_flag = False


	#検索中止用の変数がTrueなら、関数を終了する
	#どこが処理のボトルネックになるか予想しかねるので、この関数では2箇所に設置する
	if caller_object.get_search_stop_flag() is True:
		return False


	#ファイルのリストをファイル名でフィルタリングする
	if search_name != "":

		if name_regexp_flag is True:
			temporary_list = []

			if name_caps is True:
				for i in filelist:
					if re.search( search_name, i[ "filename" ] ):
						temporary_list.append( i )

			else:
				for i in filelist:
					if re.search( search_name, i[ "filename" ], re.I ):
						temporary_list.append( i )

			filelist = copy.copy( temporary_list )

		else:
			temporary_list = []

			if name_caps is True:
				for i in filelist:
					if fnmatch.fnmatch( i[ "filename" ], search_name ):
						temporary_list.append( i )

			else:
				for i in filelist:
					if fnmatch.fnmatch( i[ "filename" ].lower(), search_name.lower() ):
						temporary_list.append( i )

			filelist = copy.copy( temporary_list )


	#ファイルのリストを最小ファイルサイズでフィルタリングする
	if min_size != 0:

		if max_size != 0 and min_size > max_size:
			#エラーメッセージのダイアログを出すかもしれない
			pass

		else:
			temporary_list = []

			for i in filelist:
				if i[ "size" ] >= min_size:
					temporary_list.append( i )

			filelist = copy.copy( temporary_list )


	#ファイルのリストを最大ファイルサイズでフィルタリングする
	if max_size != 0:

		if min_size > max_size:
			#エラーメッセージのダイアログを出すかもしれない
			pass

		else:
			temporary_list = []

			for i in filelist:
				if i[ "size" ] <= max_size:
					temporary_list.append( i )

			filelist = copy.copy( temporary_list )


	#ファイルのリストを更新日時ないし作成日時でフィルタリングする
	if time_point != 0:
		#Epoch形式の現在時刻の取得はtime.strftime( "%s" )
		temporary_list = []

		if time_mode == "update":

			if time_direction == "after":

				for i in filelist:
					if i[ "update-time" ] >= time_point:
						temporary_list.append( i )

			else:

				for i in filelist:
					if i[ "update-time" ] <= time_point:
						temporary_list.append( i )

		else:

			if time_direction == "after":

				for i in filelist:
					if os.path.getctime( i[ "filepath" ] ) >= time_point:
						temporary_list.append( i )

			else:

				for i in filelist:
					if os.path.getctime( i[ "filepath" ] ) <= time_point:
						temporary_list.append( i )
			
		filelist = copy.copy( temporary_list )


	#ファイル内検索の事前準備
	#正規表現検索であっても、検索語が正規表現として成立しない場合は
	#エラーになるので、検索しないようにする。
	if search_word != "":
		try:
			re.compile( search_word )

		except:
			search_word_regexp_check = False


	#ファイル内検索
	if search_word != "" and search_word_regexp_check is True:
		temporary_list = []

		for i in filelist:

			for j in file_contents_search( caller_object = caller_object, textfile_path = i[ "filepath" ], search_word = search_word, word_regexp = word_regexp, word_caps = word_caps, side_sight = side_sight ):
				j.update( i )
				temporary_list.append( j )

			#検索中止用の変数がTrueなら、関数を終了する
			if caller_object.get_search_stop_flag() is True:
				return False
			
		filelist = copy.copy( temporary_list )

	elif search_word != "" and search_word_regexp_check is False:
		for i in filelist:
			i.update( { "line" : 0, "hit" : 0, "max_hit" : 0, "hit_str" : "検索語が正しい正規表現ではないので検索していません" } )
				

	return filelist


class FileInfoList( wx.ListCtrl ):

	def __init__( self, *args, **kwargs ):
		wx.ListCtrl.__init__( self, *args, **kwargs )
		self.table_list = [ [] ]

		self.filename_colmn_width_limit = -1
		self.description_colmn_width_limit = -1

		self.column_list = [ "ファイル名", "順", "行", "内容", "サイズ", "更新日時", "作成日時", "ファイルのパス" ]
		for n in range( len( self.column_list ) ):
			self.InsertColumn( n, self.column_list[ n ], wx.LIST_FORMAT_LEFT )

	def OnGetItemText( self, row, col ):
		return self.table_list[row][col]

	def setlist( self, list ):
		self.table_list = list

	def set_fname_col_widthlimit( self, width_limit ):
		if type( width_limit ) is int:
			self.filename_colmn_width_limit = width_limit
		else:
			print( "FileInfoListクラスに渡された列幅上限値が整数ではありません。" )

	def set_desc_col_widthlimit( self, width_limit ):
		if type( width_limit ) is int:
			self.description_colmn_width_limit = width_limit
		else:
			print( "FileInfoListクラスに渡された列幅上限値が整数ではありません。" )

	def showlist( self ):
		self.DeleteAllItems()

		#二次元配列の内容を配置していく
		#各行の先頭の追加時のみコマンドが違う（行を追加する命令なのか？）のでややこしい
		#SetItemCountを使えば簡単だが、そのためにはスタイルをwx.LC_VIRTUALにしないといけない。
		#（これの制作時点で）wx.LC_VIRTUALではwx.LIST_AUTOSIZEによる列幅の自動調整が動かないらしいので
		#InsertItem＆SetItemを使う面倒な方法に頼るしかなかった。
		for line in range( len( self.table_list ) ):

			#一行分の要素の個数か列名の個数か小さい方を配置回数にする
			if len( self.table_list[ line ] ) < len( self.column_list ):
				line_length = len( self.table_list[ line ] )
			else:
				line_length = len( self.column_list )

			for i in range( line_length ):
				if i == 0:
					self.InsertItem( line, self.table_list[ line ][ i ] )
				else:
					self.SetItem( line, i, self.table_list[ line ][ i ] )

		#列幅の自動調整（wx.LIST_AUTOSIZEは、その列にあるアイテムの最大長さに合わせるらしい）
		for j in range( len( self.column_list ) ):
			self.SetColumnWidth( j, wx.LIST_AUTOSIZE )

		#自動調整の結果として”ファイル名”の列幅が上限を超えたら制限する
		if self.filename_colmn_width_limit >= 0 and self.GetColumnWidth(0) > self.filename_colmn_width_limit:
			self.SetColumnWidth( 0, self.filename_colmn_width_limit )

			#列名を「列幅制限中」が付け足されたものに変更する
			temporary_listitem = self.GetColumn( 0 )
			temporary_listitem.SetText( "ファイル名（列幅制限中）" )
			self.SetColumn( 0, temporary_listitem )

		else:
			#上限を超えなければ、前回の検索で「列幅制限中」が付いた場合を考え列名をリセットする
			temporary_listitem = self.GetColumn( 0 )
			temporary_listitem.SetText( "ファイル名" )
			self.SetColumn( 0, temporary_listitem )

		#自動調整の結果として”行内容”の列幅が上限を超えたら制限する
		if self.description_colmn_width_limit >= 0 and self.GetColumnWidth(3) > self.description_colmn_width_limit:
			self.SetColumnWidth( 3, self.description_colmn_width_limit )

			#列名を「列幅制限中」が付け足されたものに変更する
			temporary_listitem = self.GetColumn( 3 )
			temporary_listitem.SetText( "内容（列幅制限中）" )
			self.SetColumn( 3, temporary_listitem )

		else:
			#上限を超えなければ、前回の検索で「列幅制限中」が付いた場合を考え列名をリセットする
			temporary_listitem = self.GetColumn( 3 )
			temporary_listitem.SetText( "内容" )
			self.SetColumn( 3, temporary_listitem )


class extended_frame( wx.Frame ):

	def __init__( self, *args, **kwargs ):
		wx.Frame.__init__( self, *args, **kwargs )

		self.target_directory = ""
		self.ignore_subdir = False
		self.search_name = ""
		self.name_regexp = False
		self.name_caps = False
		self.search_word = ""
		self.word_regexp = False
		self.word_caps = False
		self.min_size = 0
		self.min_size_unit = "mb"
		self.max_size = 0
		self.max_size_unit = "mb"
		self.time_number = 0
		self.time_unit = "day"
		self.time_direction = "after"
		self.time_mode = "update"

		self.side_value = 36 #内容表示の上限を半角何文字分にするかの片側（半分）の値
		self.temporary_side_value = 1
		self.filename_col_width_limit = -1
		self.description_col_width_limit = -1

		self.now_epoch = 0
		self.time_point = 0

		self.result_dictlist = []
		self.itemlist = []

		self.search_stop_flag = False

		##一段目
		self.search_name_input = wx.TextCtrl( self, wx.ID_ANY, self.search_name, style=wx.TE_PROCESS_ENTER )
		self.checkbox_name_regexp = wx.CheckBox( self, wx.ID_ANY, "正規表現" )
		self.checkbox_name_caps = wx.CheckBox( self, wx.ID_ANY, "大小区別" )
		self.search_word_input = wx.TextCtrl( self, wx.ID_ANY, self.search_word, style=wx.TE_PROCESS_ENTER )
		self.checkbox_word_regexp = wx.CheckBox( self, wx.ID_ANY, "正規表現" )
		self.checkbox_word_caps = wx.CheckBox( self, wx.ID_ANY, "大小区別" )

		#引数の指定がない場合に備えて、まずデフォルト値でGUIを設定していく
		if self.name_regexp is True:
			self.checkbox_name_regexp.SetValue( True )
		else:
			self.checkbox_name_regexp.SetValue( False )

		if self.checkbox_name_caps is True:
			self.checkbox_name_caps.SetValue( True )
		else:
			self.checkbox_name_caps.SetValue( False )

		if self.word_regexp is True:
			self.checkbox_word_regexp.SetValue( True )
		else:
			self.checkbox_word_regexp.SetValue( False )

		if self.word_caps is True:
			self.checkbox_word_caps.SetValue( True )
		else:
			self.checkbox_word_caps.SetValue( False )

		#バインド
		self.search_name_input.Bind( wx.EVT_TEXT_ENTER, self.search_thread_control )
		self.search_word_input.Bind( wx.EVT_TEXT_ENTER, self.search_thread_control )

		#1行にまとめる
		self.line1_sizer = wx.BoxSizer( wx.HORIZONTAL )
		self.line1_sizer.Add( wx.StaticText( self, wx.ID_ANY, "ファイル名：" ) )
		self.line1_sizer.Add( self.search_name_input, 1, wx.LEFT | wx.RIGHT | wx.EXPAND )
		self.line1_sizer.Add( self.checkbox_name_regexp )
		self.line1_sizer.Add( self.checkbox_name_caps )
		self.line1_sizer.Add( wx.StaticLine( self, style = wx.LI_VERTICAL ), 0, wx.LEFT | wx.RIGHT, 10 )
		self.line1_sizer.Add( wx.StaticText( self, wx.ID_ANY, "ファイル内検索：" ) )
		self.line1_sizer.Add( self.search_word_input, 1, wx.LEFT | wx.RIGHT | wx.EXPAND )
		self.line1_sizer.Add( self.checkbox_word_regexp )
		self.line1_sizer.Add( self.checkbox_word_caps )

		##二段目
		self.directory_input = wx.TextCtrl( self, wx.ID_ANY, self.target_directory, style=wx.TE_PROCESS_ENTER )
		self.choice_directory_button = wx.Button( self, wx.ID_ANY, "選", size = ( 40, -1 ) )
		self.checkbox_ignore_subdir = wx.CheckBox( self, wx.ID_ANY, "サブディレクトリは検索しない" )

		if self.ignore_subdir is True:
			self.checkbox_ignore_subdir.SetValue( True )
		else:
			self.checkbox_ignore_subdir.SetValue( False )

		#バインド
		self.directory_input.Bind( wx.EVT_TEXT_ENTER, self.search_thread_control )
		self.choice_directory_button.Bind( wx.EVT_BUTTON, self.change_dir_dialog )

		#1行にまとめる
		self.line2_sizer = wx.BoxSizer( wx.HORIZONTAL )
		self.line2_sizer.Add( wx.StaticText( self, wx.ID_ANY, "検索するフォルダ：" ))
		self.line2_sizer.Add( self.directory_input, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 10 )
		self.line2_sizer.Add( self.choice_directory_button )
		self.line2_sizer.Add( self.checkbox_ignore_subdir, 0, wx.LEFT | wx.EXPAND, 10 )

		##三段目
		self.minsize_input = wx.SpinCtrl( self, wx.ID_ANY, value = str( self.min_size ), min = 0, max = 10000, size = ( 110, 30 ) )

		self.size_unit_array = ( "MB", "GB", "KB", "B" )
		self.combobox_min_unit = wx.ComboBox( self, wx.ID_ANY, "最小ファイルサイズ", choices = self.size_unit_array, style = wx.CB_READONLY )

		self.maxsize_input = wx.SpinCtrl( self, wx.ID_ANY, value = str( self.max_size ) , min = 0, max = 10000, size = ( 110, 30 ) )
		self.combobox_max_unit = wx.ComboBox( self, wx.ID_ANY, "最大ファイルサイズ", choices = self.size_unit_array, style = wx.CB_READONLY )

		self.time_input = wx.SpinCtrl( self, wx.ID_ANY, value = str( self.time_number ) , min = 0, max = 10000, size = ( 110, 30 ) )

		self.time_unit_array = ( "時間", "日", "月", "年" )
		self.combobox_time_unit = wx.ComboBox( self, wx.ID_ANY, "時間", choices = self.time_unit_array, style = wx.CB_READONLY )

		self.time_direction_array = ( "後", "前" )
		self.combobox_time_direction = wx.ComboBox( self, wx.ID_ANY, "時間", choices = self.time_direction_array, style = wx.CB_READONLY )

		self.time_mode_array = ( "更新", "作成" )
		self.combobox_time_mode = wx.ComboBox( self, wx.ID_ANY, "時間", choices = self.time_mode_array, style = wx.CB_READONLY )

		self.search_button = wx.Button( self, wx.ID_ANY, "検索" )

		self.close_button = wx.Button( self, wx.ID_ANY, "終了" )

		if self.min_size_unit.lower() == "kb":
			self.combobox_min_unit.SetSelection( 0 )
		elif self.min_size_unit.lower() == "mb":
			self.combobox_min_unit.SetSelection( 1 )
		else:
			self.combobox_min_unit.SetSelection( 2 )

		if self.max_size_unit.lower() == "kb":
			self.combobox_max_unit.SetSelection( 0 )
		elif self.max_size_unit.lower() == "mb":
			self.combobox_max_unit.SetSelection( 1 )
		else:
			self.combobox_max_unit.SetSelection( 2 )

		if self.time_unit.lower() == "year":
			self.combobox_time_unit.SetSelection( 3 )
		elif self.time_unit.lower() == "month":
			self.combobox_time_unit.SetSelection( 2 )
		elif self.time_unit.lower() == "hour":
			self.combobox_time_unit.SetSelection( 0 )
		else:
			self.combobox_time_unit.SetSelection( 1 )

		if self.time_direction.lower() == "after":
			self.combobox_time_direction.SetSelection( 0 )
		else:
			self.combobox_time_direction.SetSelection( 1 )

		if self.time_mode.lower() == "update":
			self.combobox_time_mode.SetSelection( 0 )
		else:
			self.combobox_time_mode.SetSelection( 1 )

		#バインド
		self.search_button.Bind( wx.EVT_BUTTON, self.search_thread_control )
		self.close_button.Bind( wx.EVT_BUTTON, self.closing )

		#1行にまとめる
		self.line3_sizer = wx.BoxSizer( wx.HORIZONTAL )
		self.line3_sizer.Add( wx.StaticText( self, wx.ID_ANY, "最小" ) )
		self.line3_sizer.Add( self.minsize_input )
		self.line3_sizer.Add( self.combobox_min_unit )
		self.line3_sizer.Add( wx.StaticText( self, wx.ID_ANY, " - 最大" ) )
		self.line3_sizer.Add( self.maxsize_input )
		self.line3_sizer.Add( self.combobox_max_unit )
		self.line3_sizer.Add( wx.StaticText( self, wx.ID_ANY, "　更新日：" ) )
		self.line3_sizer.Add( self.time_input )
		self.line3_sizer.Add( self.combobox_time_unit )
		self.line3_sizer.Add( wx.StaticText( self, wx.ID_ANY, "前より" ) )
		self.line3_sizer.Add( self.combobox_time_direction )
		self.line3_sizer.Add( wx.StaticText( self, wx.ID_ANY, "に" ))
		self.line3_sizer.Add( self.combobox_time_mode )
		self.line3_sizer.Add( wx.StaticText( self, wx.ID_ANY, "されたファイル" ) )
		self.line3_sizer.Add( self.search_button, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 4 )
		self.line3_sizer.Add( self.close_button, 1, wx.LEFT | wx.RIGHT | wx.EXPAND )

		#検索結果を表示する領域
		self.result_listctrl = FileInfoList( self, wx.ID_ANY, style=wx.LC_REPORT )
		self.result_listctrl.setlist( self.itemlist )

		#コマンドライン引数からの設定値取得（の一部前倒し）
		if "filename-column-width-limit" in setting_dictionary:
			self.filename_col_width_limit = setting_dictionary[ "filename-column-width-limit" ]

		if "description-column-width-limit" in setting_dictionary:
			self.description_col_width_limit = setting_dictionary[ "description-column-width-limit" ]
		self.result_listctrl.set_fname_col_widthlimit( self.filename_col_width_limit )
		self.result_listctrl.set_desc_col_widthlimit( self.description_col_width_limit )

		#検索結果をダブルクリックした場合の処理をバインド
		self.result_listctrl.Bind( wx.EVT_LIST_ITEM_ACTIVATED, self.sendline )

		sizer = wx.BoxSizer( wx.VERTICAL )
		sizer.Add( self.line1_sizer, 0, wx.ALL | wx.EXPAND, 4 )
		sizer.Add( self.line2_sizer, 0, wx.ALL | wx.EXPAND, 4 )
		sizer.Add( self.line3_sizer, 0, wx.ALL | wx.EXPAND, 4 )
		sizer.Add( self.result_listctrl, 1, wx.ALL | wx.EXPAND, 4 )
		self.SetSizer( sizer )

		#ステータスバーの設置
		self.statusbar = self.CreateStatusBar()

		#リストファイルから送り先を読み込む
		self.send_list = self.load_send_settings()

		#コマンドライン引数からの設定値取得＆反映
		if "directory" in setting_dictionary:
			self.directory_input.SetValue( setting_dictionary[ "directory" ] )

		if "name" in setting_dictionary:
			self.search_name_input.SetValue( setting_dictionary[ "name" ] )

		if "word" in setting_dictionary:
			self.search_word_input.SetValue( setting_dictionary[ "word" ] )

		if "min-size" in setting_dictionary:
			self.minsize_input.SetValue( int( setting_dictionary[ "min-size" ] ) )

		if "min-size-unit" in setting_dictionary:
			if setting_dictionary[ "min-size-unit" ] == "KB":
				self.combobox_min_unit.SetStringSelection( "KB" )
			elif setting_dictionary[ "min-size-unit" ] == "MB":
				self.combobox_min_unit.SetStringSelection( "MB" )
			elif setting_dictionary[ "min-size-unit" ] == "GB":
				self.combobox_min_unit.SetStringSelection( "GB" )
			else:
				self.combobox_min_unit.SetStringSelection( "B" )

		if "max-size" in setting_dictionary:
			self.maxsize_input.SetValue( int( setting_dictionary[ "max-size" ] ) )

		if "max-size-unit" in setting_dictionary:
			if setting_dictionary[ "max-size-unit" ] == "KB":
				self.combobox_max_unit.SetStringSelection( "KB" )
			elif setting_dictionary[ "max-size-unit" ] == "MB":
				self.combobox_max_unit.SetStringSelection( "MB" )
			elif setting_dictionary[ "max-size-unit" ] == "GB":
				self.combobox_max_unit.SetStringSelection( "GB" )
			else:
				self.combobox_max_unit.SetStringSelection( "B" )

		if "name-regexp" in setting_dictionary:
			self.checkbox_name_regexp.SetValue( True )

		if "ignore-subdir" in setting_dictionary:
			self.checkbox_ignore_subdir.SetValue( True )

		if "name-caps" in setting_dictionary:
			self.checkbox_name_caps.SetValue( True )

		if "word-regexp" in setting_dictionary:
			self.checkbox_word_regexp.SetValue( True )

		if "word-caps" in setting_dictionary:
			self.checkbox_word_caps.SetValue( True )

		if "time" in setting_dictionary:
			self.time_input.SetValue( int( setting_dictionary[ "time" ] ) )

		if "time-unit" in setting_dictionary:
			if setting_dictionary[ "time-unit" ] == "hour":
				self.combobox_time_unit.SetSelection( 0 )
			elif setting_dictionary[ "time-unit" ] == "day":
				self.combobox_time_unit.SetSelection( 1 )
			elif setting_dictionary[ "time-unit" ] == "month":
				self.combobox_time_unit.SetSelection( 2 )
			else:
				self.combobox_time_unit.SetSelection( 3 )

		if "time-direction" in setting_dictionary:
			if setting_dictionary[ "time-direction" ] == "after":
				self.combobox_time_direction.SetSelection( 0 )
			else:
				self.combobox_time_direction.SetSelection( 1 )

		if "time-mode" in setting_dictionary:
			if setting_dictionary[ "time-mode" ] == "update":
				self.combobox_time_mode.SetSelection( 0 )
			else:
				self.combobox_time_mode.SetSelection( 1 )

		if "side-value" in setting_dictionary:
			self.side_value = setting_dictionary[ "side-value" ]

		#コマンドライン引数に「-startup-find」があれば起動と同時に検索
		if "startup-find" in setting_dictionary:
			self.search_thread_control( None )

		#起動時にフォーカスをあてる箇所を決める
		if self.search_word_input.GetValue() == "":
			self.search_name_input.SetFocus()
		else:
			self.search_word_input.SetFocus()


	#終了ボタンを押したらウィンドウを閉じて終了する
	def closing( self, event ):
		self.Close()


	#検索ボタンのラベルに応じて、ファイル検索関数（start_search）をスレッドとして実行ないし停止する
	def search_thread_control( self, event ):
		current_label = self.search_button.GetLabel()

		if current_label == "検索":
			self.search_button.SetLabel( "検索中止" )
			self.thread = threading.Thread( target = self.start_search, args = ( None, ) )
			self.thread.setDaemon( True )
			self.thread.start()

		else:
			self.search_stop_flag = True


	#各パラメータを整理してファイル検索
	def start_search( self, event ):

		#まず、ステータスバーを「検索中」にする
		#スレッド化した関数の中で直接GUI操作するとウィンドウが異常終了する場合があるので
		#関数呼び出しをwx.CallAfterで包む（引数をもとの関数から分離するので変更が少し面倒だ）
		wx.CallAfter( self.SetStatusText, "検索中" )

		self.itemlist = []

		#入力欄やチェックボックスから値を取得する
		self.target_directory = self.directory_input.GetValue()
		if self.target_directory == "":
			#ディレクトリの指定がなければ、検索処理をやめる
			wx.CallAfter( self.result_listctrl.setlist, [ [ "検索を中止しました" ] ] )
			wx.CallAfter( self.result_listctrl.showlist )
			wx.CallAfter( self.statusbar.SetStatusText, "検索するディレクトリの欄が空なので検索しません" )
			#「検索中止」にしていたボタンのラベルを元に戻しておく
			wx.CallAfter( self.search_button.SetLabel, "検索" )
			wx.CallAfter( self.stop_message_dialog, "検索するディレクトリの欄が空なので検索しません" )
			return False

		elif not os.path.isdir( self.target_directory ):
			#指定されたディレクトリの存在が確認できなければ、検索処理をやめる
			wx.CallAfter( self.result_listctrl.setlist, [ [ "検索を中止しました" ] ] )
			wx.CallAfter( self.result_listctrl.showlist )
			wx.CallAfter( self.statusbar.SetStatusText, "検索するディレクトリが見つからなかったので、検索しません" )
			#「検索中止」にしていたボタンのラベルを元に戻しておく
			wx.CallAfter( self.search_button.SetLabel, "検索" )
			wx.CallAfter( self.stop_message_dialog, "検索するディレクトリが見つからなかったので、検索しません" )
			return False

		self.ignore_subdir = self.checkbox_ignore_subdir.GetValue()

		self.search_name = self.search_name_input.GetValue()

		self.name_regexp = self.checkbox_name_regexp.GetValue()
		self.name_caps = self.checkbox_name_caps.GetValue()

		# ワイルドカード検索で、検索名の中に「.」がなければ両端にワイルドカード「*」を付加。
		#「*.txt」みたいな拡張子つき検索ではない、単に「abc」だけのときに
		#「*abc*」に修正してからワイルドカード検索するということ。
		if self.name_regexp is False and not "." in self.search_name:
			self.search_name = "*" + self.search_name + "*"

		self.search_word = self.search_word_input.GetValue()

		self.word_regexp = self.checkbox_word_regexp.GetValue()
		self.word_caps = self.checkbox_word_caps.GetValue()
		self.min_size = self.minsize_input.GetValue()
		self.min_size_unit = self.combobox_min_unit.GetValue()
		self.max_size = self.maxsize_input.GetValue()
		self.max_size_unit = self.combobox_max_unit.GetValue()
		self.time_number = self.time_input.GetValue()

		self.time_unit = self.combobox_time_unit.GetValue()

		self.time_direction = self.combobox_time_direction.GetValue()
		if self.time_direction == "後":
			self.time_direction = "after"
		else:
			self.time_direction = "before"

		self.time_mode = self.combobox_time_mode.GetValue()
		if self.time_mode == "更新":
			self.time_mode = "update"
		else:
			self.time_mode = "create"

		#最小ファイルサイズを単位に基づきバイトに変換する
		if self.min_size_unit.lower() == "kb":
			self.min_size = self.min_size * 1000
		elif self.min_size_unit.lower() == "mb":
			self.min_size = self.min_size * 1000000
		elif self.min_size_unit.lower() == "gb":
			self.min_size = self.min_size * 1000000000

		#最大ファイルサイズを単位に基づきバイトに変換する
		if self.max_size_unit.lower() == "kb":
			self.max_size = self.max_size * 1000
		elif self.max_size_unit.lower() == "mb":
			self.max_size = self.max_size * 1000000
		elif self.max_size_unit.lower() == "gb":
			self.max_size = self.max_size * 1000000000

		#更新ないし作成時刻を判別する時点のエポック秒を求める
		if self.time_number == 0:
			self.time_point = 0

		else:
			self.now_epoch = int( time.time() ) #文字列で即座に得たいならtime.strftime( "%s" )
			if self.time_unit == "時間":
				self.time_point = self.now_epoch - self.time_number * 60 * 60
			elif self.time_unit == "日":
				self.time_point = self.now_epoch - self.time_number * 60 * 60 * 24
			elif self.time_unit == "月":
				self.time_point = self.now_epoch - self.time_number * 60 * 60 * 24 * 30
			elif self.time_unit == "年":
				self.time_point = self.now_epoch - self.time_number * 60 * 60 * 24 * 365

		if self.description_col_width_limit < 0:
			self.temporary_side_value = self.side_value

		#内容欄の（ピクセル単位の）列幅制限が有効になっているなら、内容の文字列制限を無効にする
		else:
			self.temporary_side_value = -1

		#検索条件の用意が終わったところで、検索の本体を稼働させる
		self.result_dictlist = search_file( caller_object = self, target_dir = self.target_directory, subdir = not( self.ignore_subdir ), search_name = self.search_name, name_regexp = self.name_regexp, name_caps = self.name_caps, search_word = self.search_word, word_regexp = self.word_regexp, word_caps = self.word_caps, min_size = self.min_size, max_size = self.max_size, time_point = self.time_point, time_direction = self.time_direction, time_mode = self.time_mode, side_sight = self.temporary_side_value )

		#検索中止用の変数がTrueなら、ステータスバーやダイアログで中止を表明して関数を終了する
		if self.search_stop_flag is True:
			wx.CallAfter( self.result_listctrl.setlist, [ [ "検索を中止しました" ] ] )
			wx.CallAfter( self.result_listctrl.showlist )
			wx.CallAfter( self.SetStatusText, "検索を中止しました" )
			#「検索中止」にしていたボタンのラベルを元に戻しておく
			wx.CallAfter( self.search_button.SetLabel, "検索" )
			wx.CallAfter( self.stop_message_dialog, "検索を中止しました" )

			self.search_stop_flag = False
			return False

		#検索結果の各行は順番が保持されない辞書なので、内容を整えつつ表示用のリストに変換する
		for i in self.result_dictlist:
			temporary_list = []
			temporary_list.append( i.get( "filename" ) )

			if "hit" in i:
				temporary_list.append( str( i[ "hit" ] ) + "/" + str( i[ "max_hit" ] ) )
			else:
				temporary_list.append( "" )

			temporary_list.append( str( i.get( "line", "" ) ) )
			temporary_list.append( i.get( "hit_str", "" ) )

			filesize = i.get( "size", "" )
			#1024の倍数だとNautilusのサイズ表示と食い違ってしまうので1000の倍数にした
			if filesize >= 1000000000:
				temporary_list.append( str( round( float( filesize / float( 1000000000 ) ), 1 ) ) + "GB" )
			elif filesize >= 1000000:
				temporary_list.append( str( round( float( filesize / float( 1000000 ) ), 1 ) ) + "MB" )
			elif filesize >= 1000:
				temporary_list.append( str( round( float( filesize / float( 1000 ) ), 1 ) ) + "KB" )
			else:
				temporary_list.append( str( filesize ) + "B" )

			temporary_list.append( time.strftime( "%Y-%m-%dT%H:%M:%S", time.localtime( i.get( "update-time" ) ) ) )
			temporary_list.append( time.strftime( "%Y-%m-%dT%H:%M:%S", time.localtime( i.get( "create-time" ) ) ) )

			temporary_list.append( i.get( "filepath" ) )

			self.itemlist.append( temporary_list )

		self.itemlist = sorted( self.itemlist, key = itemgetter(7) ) #ファイルのパスでソート

		self.result_listctrl.setlist( self.itemlist )
		wx.CallAfter( self.result_listctrl.showlist )

		#ステータスバーに該当件数を表示する
		if len( self.result_dictlist ) == 0:
			wx.CallAfter( self.SetStatusText, "条件に該当するファイルが見つかりませんでした" )

		else:
			if self.search_word == "":
				wx.CallAfter( self.SetStatusText, str( len( self.result_dictlist ) ) + "個のファイルが該当しました" )

			else:
				path_set = set( [ x[ "filepath" ] for x in self.result_dictlist ] )

				wx.CallAfter( self.SetStatusText, str( len( path_set ) ) + "個のファイル、" + str( len( self.result_dictlist ) ) + "件が該当しました" )

		#「検索中止」にしていたボタンのラベルを元に戻しておく
		wx.CallAfter( self.search_button.SetLabel, "検索" )


	#ディレクトリ選択ダイアログ
	def change_dir_dialog( self, event ):

		if self.directory_input.GetValue() != "" and os.path.isdir( self.directory_input.GetValue() ):
			d_dialog = wx.DirDialog( self, "検索するフォルダを選択してください", defaultPath = self.directory_input.GetValue() )
		else:
			d_dialog = wx.DirDialog( self, "検索するフォルダを選択してください", defaultPath = os.getcwd() )

		if d_dialog.ShowModal() == wx.ID_OK:

			dirpath = d_dialog.GetPath()

			self.directory_input.SetValue( dirpath )

		d_dialog.Destroy()


	#ファイルの送り先を記述したファイルを読み込む
	def load_send_settings( self ):
		sendline_list = []
		sendlist_filepath = os.path.join( os.path.dirname( sys.argv[0] ), "pz-send.list" )

		if not os.path.isfile( sendlist_filepath ):
			return []

		f = open( sendlist_filepath, "r" )

		for linetext in f:
			#改行削除
			linetext = linetext.rstrip( '\n' )
			linetext = linetext.rstrip( '\r' )

			command = linetext[ len( linetext.split( "," )[0] ) + 1 : ].split( " " )
			sendline_list.append( [ linetext[ 0 : len( linetext.split( "," )[0] ) ], command ] )

		f.close

		return sendline_list


	#ダブルクリックなどをした行のファイルを外部ソフトに送る
	def sendline( self, event ):
		simple_list_dialog = SimpleListDialog( title = "送り先を選んでください", size_tuple = ( 500, 700 ) , choice_list = [ x[0] for x in self.send_list ] )

		if simple_list_dialog.ShowModal() == wx.ID_OK:
			origin_command_list = self.send_list[ simple_list_dialog.GetSelection() ][1]

			start_line = self.result_listctrl.GetFirstSelected()
			selected_lines = self.result_listctrl.GetSelectedItemCount()

			for i in range( start_line, start_line + selected_lines ):
				command_list = copy.copy( origin_command_list )

				#行の内容をリストとして取得する
				fileinfo_list = []
				for j in range( len( self.itemlist[0] ) ):
					item = self.result_listctrl.GetItemText( i, j )
					fileinfo_list.append( item )

				#パスやホームディレクトリと違って、ファイル内検索をしないと
				#行番号は存在しないので、その場合は-1としておく
				#「オプション名=空白」よりは「オプション名=-1」のほうが、絶対値をとるだけで
				#1にできるので、エラーになる送り先への対処が容易だという判断による
				line_value = fileinfo_list[ 2 ]
				if line_value == "":
					line_value = "-1"

				#コマンドの中で、仮名になっていたパスや行番号を実際のものに書き換える
				for a in range( len( command_list ) ):
					command_list[ a ] = command_list[ a ].replace( "%path", fileinfo_list[ 7 ] )
					command_list[ a ] = command_list[ a ].replace( "%dir", os.path.dirname( fileinfo_list[ 7 ] ) )
					command_list[ a ] = command_list[ a ].replace( "%filename", fileinfo_list[ 0 ] )
					command_list[ a ] = command_list[ a ].replace( "%line", line_value )
					command_list[ a ] = command_list[ a ].replace( "%home", os.environ.get( "HOME" ) )
					command_list[ a ] = command_list[ a ].replace( "%scriptdir", os.path.dirname( sys.argv[0] ) )

				#調整し終わったコマンドを実行する
				subprocess.Popen( command_list )

		simple_list_dialog.Destroy()


	#ファイル名の列幅制限値を設定する関数（コマンドライン引数から、このクラスの初期化関数内で直接設定するようにしたので、現状では使わない）
	def set_colmn_width_filename( self, width_limit ):
		self.filename_col_width_limit = width_limit


	#行内容の列幅制限値を設定する関数（コマンドライン引数から、このクラスの初期化関数内で直接設定するようにしたので、現状では使わない）
	def set_colmn_width_description( self, width_limit ):
		self.description_col_width_limit = width_limit

	#検索を中止した場合に表示するダイアログ
	def stop_message_dialog( self, message = "" ):
		error_dialog =  wx.MessageDialog( None, message, "Error",wx.OK | wx.ICON_ERROR )
		error_dialog.ShowModal()
		error_dialog.Destroy()

	def get_search_stop_flag( self ):
		return self.search_stop_flag


#検出されたファイルをダブルクリックなどで選択した時に
#適用する処理の一覧を表示するためのダイアログ
#wx.SingleChoiceDialogがサイズを設定できないので、やむなく代わりを作った
class SimpleListDialog( wx.Dialog ):

	def __init__( self, title, size_tuple, choice_list ):
		wx.Dialog.__init__( self, None, -1, title, size = size_tuple )

		self.listbox = wx.ListBox( self, wx.ID_ANY, choices = choice_list )
		
		self.listbox.Bind( wx.EVT_LISTBOX_DCLICK, self.dialog_close )

		self.ok_button = wx.Button( self, wx.ID_OK, "OK" )
		self.cancel_button = wx.Button( self, wx.ID_CANCEL, "Cancel" )
		twin_buttons_sizer = wx.BoxSizer( wx.HORIZONTAL )
		twin_buttons_sizer.Add( self.ok_button, 1, wx.LEFT | wx.RIGHT, 50 )
		twin_buttons_sizer.Add( self.cancel_button, 1, wx.LEFT | wx.RIGHT, 50 )

		sizer = wx.BoxSizer( wx.VERTICAL )
		sizer.Add( self.listbox, 1, wx.ALL | wx.EXPAND, 10 )
		sizer.Add( twin_buttons_sizer, 0, wx.ALIGN_CENTER )
		self.SetSizer( sizer )

	def GetSelection( self ):
		return self.listbox.GetSelection()

	#リストをダブルクリックしたら、OKボタンを押すのと同様にwx.ID_OKを返しダイアログを閉じる
	def dialog_close( self, event ):
		self.EndModal( wx.ID_OK )



if __name__ == "__main__" :

	#引数の処理
	setting_dictionary = {}

	#このスクリプト自身が渡されたファイルとして扱われて
	#検索先ディレクトリに入るのを防ぐために、[ 1 : ]をつけて自身を除去している
	for com_line_arg in sys.argv[ 1 : ]:

		if re.match( "^-name=", com_line_arg ):
			setting_dictionary[ "name" ] = com_line_arg.split( "=" )[1]

		elif re.match( "^-word=", com_line_arg ):
			setting_dictionary[ "word" ] = com_line_arg.split( "=" )[1]

		elif re.match( "^-size=([0-9]+[KMG]?B-$|([0-9]+([KMG]?B)?)?-[0-9]+[KMG]?B)", com_line_arg ):
			size_part = com_line_arg.split( "=" )[1]

			min_part = size_part.split( "-" )[0]
			setting_dictionary[ "min-size" ] = re.findall( "[0-9]+", min_part )[0]
			setting_dictionary[ "min-size-unit" ] = re.findall( "[A-Z]+", min_part )[0]

			max_part = size_part.split( "-" )[1]
			setting_dictionary[ "max-size" ] = re.findall( "[0-9]+", max_part )[0]
			setting_dictionary[ "max-size-unit" ] = re.findall( "[A-Z]+", max_part )[0]

		elif com_line_arg.lower() == "-name-regexp=true":
			setting_dictionary[ "name-regexp" ] = True

		elif com_line_arg.lower() == "-ignore-subdir=true":
			setting_dictionary[ "ignore-subdir" ] = True

		elif com_line_arg.lower() == "-name-caps=true":
			setting_dictionary[ "name-caps" ] = True

		elif com_line_arg.lower() == "-word-regexp=true":
			setting_dictionary[ "word-regexp" ] = True

		elif com_line_arg.lower() == "-word-caps=true":
			setting_dictionary[ "word-caps" ] = True

		elif re.match( "^-time=[0-9]+[,](hour|day|month|year)[,](after|before)[,](update|create)", com_line_arg ):
			time_part = com_line_arg.split( "=" )[1]
			setting_dictionary[ "time" ],setting_dictionary[ "time-unit" ],setting_dictionary[ "time-direction" ],setting_dictionary[ "time-mode" ] = time_part.split( "," )

		elif re.match( "^-position=[0-9]+[,][0-9]+$", com_line_arg ):
			setting_dictionary[ "position" ] = com_line_arg.split( "=" )[1].split( "," )
			#引数から取得しただけでは文字列のままなので、整数に変換しておく
			setting_dictionary[ "position" ] = [ int( x ) for x in setting_dictionary[ "position" ] ]

		elif com_line_arg.lower() == "-startup-find":
			setting_dictionary[ "startup-find" ] = True

		elif os.path.isfile( com_line_arg ):
			setting_dictionary[ "directory" ] = os.path.dirname( os.path.abspath( com_line_arg ) )

		elif os.path.isdir( com_line_arg ):
			setting_dictionary[ "directory" ] = os.path.abspath( com_line_arg )

		elif re.match( "-side-value=[0-9]+$", com_line_arg ):
			setting_dictionary[ "side-value" ] = int( com_line_arg.split( "=" )[1] )

		elif re.match( "-filename-column-width-limit=[0-9]+$", com_line_arg ):
			setting_dictionary[ "filename-column-width-limit" ] = int( com_line_arg.split( "=" )[1] )

		elif re.match( "-description-column-width-limit=[0-9]+$", com_line_arg ):
			setting_dictionary[ "description-column-width-limit" ] = int( com_line_arg.split( "=" )[1] )

	#引数の処理はここまで


	application = wx.App()
	frame = extended_frame( None, wx.ID_ANY, "ファイル検索 PzSearch", size = ( 1200, 720 ) )

	if "position" in setting_dictionary:
		frame.SetPosition( tuple( setting_dictionary[ "position" ] ) )
	else:
		frame.Centre()

	frame.Show()
	
	application.MainLoop()
